from .types.v1 import key_pb2 as _key_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateKeyRegistrationRequest(_message.Message):
    __slots__ = ("cloud_region", "key_id", "managed_by", "key_type", "key_name", "cloud_account_id")
    CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    MANAGED_BY_FIELD_NUMBER: _ClassVar[int]
    KEY_TYPE_FIELD_NUMBER: _ClassVar[int]
    KEY_NAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    cloud_region: str
    key_id: str
    managed_by: str
    key_type: str
    key_name: str
    cloud_account_id: str
    def __init__(self, cloud_region: _Optional[str] = ..., key_id: _Optional[str] = ..., managed_by: _Optional[str] = ..., key_type: _Optional[str] = ..., key_name: _Optional[str] = ..., cloud_account_id: _Optional[str] = ...) -> None: ...

class CreateKeyRegistrationResponse(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: _key_pb2.Key
    def __init__(self, key: _Optional[_Union[_key_pb2.Key, _Mapping]] = ...) -> None: ...

class GetKeysRequest(_message.Message):
    __slots__ = ("filter_by_status",)
    FILTER_BY_STATUS_FIELD_NUMBER: _ClassVar[int]
    filter_by_status: str
    def __init__(self, filter_by_status: _Optional[str] = ...) -> None: ...

class GetKeysResponse(_message.Message):
    __slots__ = ("keys",)
    KEYS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[_key_pb2.Key]
    def __init__(self, keys: _Optional[_Iterable[_Union[_key_pb2.Key, _Mapping]]] = ...) -> None: ...

class GetKeyRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetKeyResponse(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: _key_pb2.Key
    def __init__(self, key: _Optional[_Union[_key_pb2.Key, _Mapping]] = ...) -> None: ...

class DeactivateFieldEncryptionKeyRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeactivateFieldEncryptionKeyResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/satellite.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/satellite.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import satellite_pb2 as admin_dot_v1_dot_types_dot_v1_dot_satellite__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/satellite.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/satellite.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"c\n\x16\x43reateSatelliteRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\")\n\x17\x43reateSatelliteResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetSatelliteByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x18GetSatelliteByIdResponse\x12:\n\tsatellite\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\tsatellite\"\x16\n\x14GetSatellitesRequest\"U\n\x15GetSatellitesResponse\x12<\n\nsatellites\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\nsatellites\"+\n\x19GetSatelliteApiKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"5\n\x1aGetSatelliteApiKeyResponse\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\"s\n\x16UpdateSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x35\n\x16termination_protection\x18\x03 \x01(\x08R\x15terminationProtection\"\x19\n\x17UpdateSatelliteResponse\"(\n\x16\x44\x65leteSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteSatelliteResponse\"\xc8\x01\n\x17SatelliteOnlineInstance\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12\x37\n\tlast_seen\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastSeen\x12\x39\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"8\n&GetOnlineInstancesBySatelliteIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"j\n\'GetOnlineInstancesBySatelliteIdResponse\x12?\n\tinstances\x18\x01 \x03(\x0b\x32!.admin.v1.SatelliteOnlineInstanceR\tinstances2\xb3\x05\n\x10SatelliteService\x12V\n\x0f\x43reateSatellite\x12 .admin.v1.CreateSatelliteRequest\x1a!.admin.v1.CreateSatelliteResponse\x12Y\n\x10GetSatelliteById\x12!.admin.v1.GetSatelliteByIdRequest\x1a\".admin.v1.GetSatelliteByIdResponse\x12P\n\rGetSatellites\x12\x1e.admin.v1.GetSatellitesRequest\x1a\x1f.admin.v1.GetSatellitesResponse\x12_\n\x12GetSatelliteApiKey\x12#.admin.v1.GetSatelliteApiKeyRequest\x1a$.admin.v1.GetSatelliteApiKeyResponse\x12\x88\x01\n\x1fGetOnlineInstancesBySatelliteId\x12\x30.admin.v1.GetOnlineInstancesBySatelliteIdRequest\x1a\x31.admin.v1.GetOnlineInstancesBySatelliteIdResponse\"\x00\x12V\n\x0fUpdateSatellite\x12 .admin.v1.UpdateSatelliteRequest\x1a!.admin.v1.UpdateSatelliteResponse\x12V\n\x0f\x44\x65leteSatellite\x12 .admin.v1.DeleteSatelliteRequest\x1a!.admin.v1.DeleteSatelliteResponseB\xa4\x01\n\x0c\x63om.admin.v1B\x0eSatelliteProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.satellite_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016SatelliteProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESATELLITEREQUEST']._serialized_start=106
  _globals['_CREATESATELLITEREQUEST']._serialized_end=205
  _globals['_CREATESATELLITERESPONSE']._serialized_start=207
  _globals['_CREATESATELLITERESPONSE']._serialized_end=248
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_start=250
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_end=291
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_start=293
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_end=379
  _globals['_GETSATELLITESREQUEST']._serialized_start=381
  _globals['_GETSATELLITESREQUEST']._serialized_end=403
  _globals['_GETSATELLITESRESPONSE']._serialized_start=405
  _globals['_GETSATELLITESRESPONSE']._serialized_end=490
  _globals['_GETSATELLITEAPIKEYREQUEST']._serialized_start=492
  _globals['_GETSATELLITEAPIKEYREQUEST']._serialized_end=535
  _globals['_GETSATELLITEAPIKEYRESPONSE']._serialized_start=537
  _globals['_GETSATELLITEAPIKEYRESPONSE']._serialized_end=590
  _globals['_UPDATESATELLITEREQUEST']._serialized_start=592
  _globals['_UPDATESATELLITEREQUEST']._serialized_end=707
  _globals['_UPDATESATELLITERESPONSE']._serialized_start=709
  _globals['_UPDATESATELLITERESPONSE']._serialized_end=734
  _globals['_DELETESATELLITEREQUEST']._serialized_start=736
  _globals['_DELETESATELLITEREQUEST']._serialized_end=776
  _globals['_DELETESATELLITERESPONSE']._serialized_start=778
  _globals['_DELETESATELLITERESPONSE']._serialized_end=803
  _globals['_SATELLITEONLINEINSTANCE']._serialized_start=806
  _globals['_SATELLITEONLINEINSTANCE']._serialized_end=1006
  _globals['_GETONLINEINSTANCESBYSATELLITEIDREQUEST']._serialized_start=1008
  _globals['_GETONLINEINSTANCESBYSATELLITEIDREQUEST']._serialized_end=1064
  _globals['_GETONLINEINSTANCESBYSATELLITEIDRESPONSE']._serialized_start=1066
  _globals['_GETONLINEINSTANCESBYSATELLITEIDRESPONSE']._serialized_end=1172
  _globals['_SATELLITESERVICE']._serialized_start=1175
  _globals['_SATELLITESERVICE']._serialized_end=1866
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_datahub_pb2 import (
	CreateDatahubIntegrationRequest,
	CreateDatahubIntegrationResponse,
	GetDatahubIntegrationRequest,
	GetDatahubIntegrationResponse,
	UpdateDatahubIntegrationRequest,
	UpdateDatahubIntegrationResponse,
	RefreshWebhookTokenRequest,
	RefreshWebhookTokenResponse,
	DeleteDatahubIntegrationRequest,
	DeleteDatahubIntegrationResponse,
)

from .gen.admin.v1.integration_datahub_pb2_grpc import DatahubServiceStub
class DatahubService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = DatahubServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateDatahubIntegration(self, request: CreateDatahubIntegrationRequest) -> CreateDatahubIntegrationResponse:
		return self.stub.CreateDatahubIntegration(request, metadata=self.headers)

	def GetDatahubIntegration(self, request: GetDatahubIntegrationRequest) -> GetDatahubIntegrationResponse:
		return self.stub.GetDatahubIntegration(request, metadata=self.headers)

	def UpdateDatahubIntegration(self, request: UpdateDatahubIntegrationRequest) -> UpdateDatahubIntegrationResponse:
		return self.stub.UpdateDatahubIntegration(request, metadata=self.headers)

	def RefreshWebhookToken(self, request: RefreshWebhookTokenRequest) -> RefreshWebhookTokenResponse:
		return self.stub.RefreshWebhookToken(request, metadata=self.headers)

	def DeleteDatahubIntegration(self, request: DeleteDatahubIntegrationRequest) -> DeleteDatahubIntegrationResponse:
		return self.stub.DeleteDatahubIntegration(request, metadata=self.headers)




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_cloud_pb2 as admin_dot_v1_dot_integration__cloud__pb2


class CloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDataplaneById = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.FromString,
                _registered_method=True)
        self.GetDataplaneRoutesById = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneRoutesById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.FromString,
                _registered_method=True)
        self.GetDataplaneStacksByCloudAccountId = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneStacksByCloudAccountId',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.FromString,
                _registered_method=True)
        self.CreateAwsConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/CreateAwsConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.FromString,
                _registered_method=True)
        self.DeleteAwsConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/DeleteAwsConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.FromString,
                _registered_method=True)
        self.GetIntegrationsCloudAccountById = channel.unary_unary(
                '/admin.v1.CloudService/GetIntegrationsCloudAccountById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.FromString,
                _registered_method=True)
        self.GetIntegrationsCloudAccounts = channel.unary_unary(
                '/admin.v1.CloudService/GetIntegrationsCloudAccounts',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.FromString,
                _registered_method=True)
        self.CreateGcpConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/CreateGcpConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.FromString,
                _registered_method=True)


class CloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDataplaneById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataplaneRoutesById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataplaneStacksByCloudAccountId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAwsConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAwsConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationsCloudAccountById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationsCloudAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGcpConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDataplaneById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.SerializeToString,
            ),
            'GetDataplaneRoutesById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneRoutesById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.SerializeToString,
            ),
            'GetDataplaneStacksByCloudAccountId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneStacksByCloudAccountId,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.SerializeToString,
            ),
            'CreateAwsConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAwsConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.SerializeToString,
            ),
            'DeleteAwsConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAwsConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.SerializeToString,
            ),
            'GetIntegrationsCloudAccountById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationsCloudAccountById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.SerializeToString,
            ),
            'GetIntegrationsCloudAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationsCloudAccounts,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.SerializeToString,
            ),
            'CreateGcpConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGcpConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.CloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.CloudService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDataplaneById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneById',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataplaneRoutesById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneRoutesById',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataplaneStacksByCloudAccountId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneStacksByCloudAccountId',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAwsConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/CreateAwsConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteAwsConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/DeleteAwsConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationsCloudAccountById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetIntegrationsCloudAccountById',
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationsCloudAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetIntegrationsCloudAccounts',
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateGcpConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/CreateGcpConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetPermissionsByServiceRequest(_message.Message):
    __slots__ = ("service",)
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    service: str
    def __init__(self, service: _Optional[str] = ...) -> None: ...

class GetPermissionsByServiceResponse(_message.Message):
    __slots__ = ("permissions",)
    class PermissionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bool
        def __init__(self, key: _Optional[str] = ..., value: bool = ...) -> None: ...
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.ScalarMap[str, bool]
    def __init__(self, permissions: _Optional[_Mapping[str, bool]] = ...) -> None: ...

class GetPermissionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetPermissionsResponse(_message.Message):
    __slots__ = ("permissions",)
    class PermissionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bool
        def __init__(self, key: _Optional[str] = ..., value: bool = ...) -> None: ...
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.ScalarMap[str, bool]
    def __init__(self, permissions: _Optional[_Mapping[str, bool]] = ...) -> None: ...



import grpc


from .gen.admin.v1.permissions_pb2 import (
	GetPermissionsByServiceRequest,
	GetPermissionsByServiceResponse,
	GetPermissionsRequest,
	GetPermissionsResponse,
)

from .gen.admin.v1.permissions_pb2_grpc import PermissionServiceStub
class PermissionService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = PermissionServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetPermissions(self, request: GetPermissionsRequest) -> GetPermissionsResponse:
		return self.stub.GetPermissions(request, metadata=self.headers)

	def GetPermissionsByService(self, request: GetPermissionsByServiceRequest) -> GetPermissionsByServiceResponse:
		return self.stub.GetPermissionsByService(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/etl.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/etl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/etl.proto\x12\x11\x61\x64min.v1.types.v1\"f\n\x08\x45TLGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\"\xc5\x02\n\x0c\x45TLConnector\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12%\n\x0e\x64\x65stination_id\x18\x04 \x01(\tR\rdestinationId\x12\x19\n\x08group_id\x18\x05 \x01(\tR\x07groupId\x12%\n\x0e\x63onnector_type\x18\x06 \x01(\tR\rconnectorType\x12!\n\x0cservice_name\x18\x07 \x01(\tR\x0bserviceName\x12\x1b\n\thost_name\x18\x08 \x01(\tR\x08hostName\x12#\n\rdatabase_name\x18\t \x01(\tR\x0c\x64\x61tabaseName\x12\x1f\n\x0blast_synced\x18\n \x01(\x05R\nlastSynced\"\xa4\x02\n\x0e\x45TLDestination\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12\x19\n\x08group_id\x18\x04 \x01(\tR\x07groupId\x12)\n\x10\x64\x65stination_type\x18\x05 \x01(\tR\x0f\x64\x65stinationType\x12!\n\x0cservice_name\x18\x06 \x01(\tR\x0bserviceName\x12\x1b\n\thost_name\x18\x07 \x01(\tR\x08hostName\x12#\n\rdatabase_name\x18\x08 \x01(\tR\x0c\x64\x61tabaseName\x12\x1f\n\x0blast_synced\x18\t \x01(\x05R\nlastSynced\"\x9b\x02\n\x10\x45TLSchemaLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12#\n\rsource_schema\x18\x06 \x01(\tR\x0csourceSchema\x12-\n\x12\x64\x65stination_schema\x18\x07 \x01(\tR\x11\x64\x65stinationSchema\x12!\n\x0clast_updated\x18\x08 \x01(\x05R\x0blastUpdated\"\xb3\x02\n\x0f\x45TLTableLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12\x1b\n\tschema_id\x18\x06 \x01(\tR\x08schemaId\x12!\n\x0csource_table\x18\x07 \x01(\tR\x0bsourceTable\x12+\n\x11\x64\x65stination_table\x18\x08 \x01(\tR\x10\x64\x65stinationTable\x12!\n\x0clast_updated\x18\t \x01(\x05R\x0blastUpdated\"\xda\x03\n\x10\x45TLColumnLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12\x1b\n\tschema_id\x18\x06 \x01(\tR\x08schemaId\x12\x19\n\x08table_id\x18\x07 \x01(\tR\x07tableId\x12#\n\rsource_column\x18\x08 \x01(\tR\x0csourceColumn\x12-\n\x12\x64\x65stination_column\x18\t \x01(\tR\x11\x64\x65stinationColumn\x12(\n\x10source_data_type\x18\n \x01(\tR\x0esourceDataType\x12\x32\n\x15\x64\x65stination_data_type\x18\x0b \x01(\tR\x13\x64\x65stinationDataType\x12$\n\x0eis_primary_key\x18\x0c \x01(\x08R\x0cisPrimaryKey\x12$\n\x0eis_foreign_key\x18\r \x01(\x08R\x0cisForeignKey\"\xd0\x01\n\nETLMapping\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12!\n\x0c\x63onnector_id\x18\x03 \x01(\tR\x0b\x63onnectorId\x12\x32\n\x15platform_connector_id\x18\x04 \x01(\tR\x13platformConnectorId\x12#\n\rplatform_type\x18\x05 \x01(\tR\x0cplatformType\x12\x1f\n\x0blast_synced\x18\x06 \x01(\x05R\nlastSyncedB\xd6\x01\n\x15\x63om.admin.v1.types.v1B\x08\x45tlProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.etl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010EtlProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_ETLGROUP']._serialized_start=50
  _globals['_ETLGROUP']._serialized_end=152
  _globals['_ETLCONNECTOR']._serialized_start=155
  _globals['_ETLCONNECTOR']._serialized_end=480
  _globals['_ETLDESTINATION']._serialized_start=483
  _globals['_ETLDESTINATION']._serialized_end=775
  _globals['_ETLSCHEMALINEAGE']._serialized_start=778
  _globals['_ETLSCHEMALINEAGE']._serialized_end=1061
  _globals['_ETLTABLELINEAGE']._serialized_start=1064
  _globals['_ETLTABLELINEAGE']._serialized_end=1371
  _globals['_ETLCOLUMNLINEAGE']._serialized_start=1374
  _globals['_ETLCOLUMNLINEAGE']._serialized_end=1848
  _globals['_ETLMAPPING']._serialized_start=1851
  _globals['_ETLMAPPING']._serialized_end=2059
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import native_user_pb2 as admin_dot_v1_dot_native__user__pb2


class NativeUserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNativeUser = channel.unary_unary(
                '/admin.v1.NativeUserService/CreateNativeUser',
                request_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserResponse.FromString,
                _registered_method=True)
        self.GetNativeUser = channel.unary_unary(
                '/admin.v1.NativeUserService/GetNativeUser',
                request_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserResponse.FromString,
                _registered_method=True)
        self.GetNativeUsers = channel.unary_unary(
                '/admin.v1.NativeUserService/GetNativeUsers',
                request_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUsersRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUsersResponse.FromString,
                _registered_method=True)
        self.DeleteNativeUser = channel.unary_unary(
                '/admin.v1.NativeUserService/DeleteNativeUser',
                request_serializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserResponse.FromString,
                _registered_method=True)
        self.UpdateNativeUserSecret = channel.unary_unary(
                '/admin.v1.NativeUserService/UpdateNativeUserSecret',
                request_serializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretResponse.FromString,
                _registered_method=True)
        self.SetNativeUserAsDefault = channel.unary_unary(
                '/admin.v1.NativeUserService/SetNativeUserAsDefault',
                request_serializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultResponse.FromString,
                _registered_method=True)
        self.SetNativeUserTerminationProtection = channel.unary_unary(
                '/admin.v1.NativeUserService/SetNativeUserTerminationProtection',
                request_serializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionResponse.FromString,
                _registered_method=True)
        self.CreateNativeUserIdentityLink = channel.unary_unary(
                '/admin.v1.NativeUserService/CreateNativeUserIdentityLink',
                request_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkResponse.FromString,
                _registered_method=True)
        self.CreateNativeUserIdentityLinkV2 = channel.unary_unary(
                '/admin.v1.NativeUserService/CreateNativeUserIdentityLinkV2',
                request_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Response.FromString,
                _registered_method=True)
        self.GetNativeUserIdentityLink = channel.unary_unary(
                '/admin.v1.NativeUserService/GetNativeUserIdentityLink',
                request_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkResponse.FromString,
                _registered_method=True)
        self.UpdateNativeUserIdentityLink = channel.unary_unary(
                '/admin.v1.NativeUserService/UpdateNativeUserIdentityLink',
                request_serializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkResponse.FromString,
                _registered_method=True)
        self.DeleteNativeUserIdentityLink = channel.unary_unary(
                '/admin.v1.NativeUserService/DeleteNativeUserIdentityLink',
                request_serializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkResponse.FromString,
                _registered_method=True)


class NativeUserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateNativeUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNativeUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNativeUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNativeUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNativeUserSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNativeUserAsDefault(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNativeUserTerminationProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNativeUserIdentityLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNativeUserIdentityLinkV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNativeUserIdentityLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNativeUserIdentityLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNativeUserIdentityLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NativeUserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNativeUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNativeUser,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserResponse.SerializeToString,
            ),
            'GetNativeUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNativeUser,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserResponse.SerializeToString,
            ),
            'GetNativeUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNativeUsers,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUsersRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUsersResponse.SerializeToString,
            ),
            'DeleteNativeUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNativeUser,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserResponse.SerializeToString,
            ),
            'UpdateNativeUserSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNativeUserSecret,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretResponse.SerializeToString,
            ),
            'SetNativeUserAsDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNativeUserAsDefault,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultResponse.SerializeToString,
            ),
            'SetNativeUserTerminationProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNativeUserTerminationProtection,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionResponse.SerializeToString,
            ),
            'CreateNativeUserIdentityLink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNativeUserIdentityLink,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkResponse.SerializeToString,
            ),
            'CreateNativeUserIdentityLinkV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNativeUserIdentityLinkV2,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Response.SerializeToString,
            ),
            'GetNativeUserIdentityLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNativeUserIdentityLink,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkResponse.SerializeToString,
            ),
            'UpdateNativeUserIdentityLink': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNativeUserIdentityLink,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkResponse.SerializeToString,
            ),
            'DeleteNativeUserIdentityLink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNativeUserIdentityLink,
                    request_deserializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.NativeUserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.NativeUserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class NativeUserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateNativeUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/CreateNativeUser',
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNativeUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/GetNativeUser',
            admin_dot_v1_dot_native__user__pb2.GetNativeUserRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.GetNativeUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNativeUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/GetNativeUsers',
            admin_dot_v1_dot_native__user__pb2.GetNativeUsersRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.GetNativeUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteNativeUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/DeleteNativeUser',
            admin_dot_v1_dot_native__user__pb2.DeleteNativeUserRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.DeleteNativeUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateNativeUserSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/UpdateNativeUserSecret',
            admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.UpdateNativeUserSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetNativeUserAsDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/SetNativeUserAsDefault',
            admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.SetNativeUserAsDefaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetNativeUserTerminationProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/SetNativeUserTerminationProtection',
            admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.SetNativeUserTerminationProtectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNativeUserIdentityLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/CreateNativeUserIdentityLink',
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNativeUserIdentityLinkV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/CreateNativeUserIdentityLinkV2',
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Request.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.CreateNativeUserIdentityLinkV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNativeUserIdentityLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/GetNativeUserIdentityLink',
            admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.GetNativeUserIdentityLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateNativeUserIdentityLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/UpdateNativeUserIdentityLink',
            admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.UpdateNativeUserIdentityLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteNativeUserIdentityLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.NativeUserService/DeleteNativeUserIdentityLink',
            admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkRequest.SerializeToString,
            admin_dot_v1_dot_native__user__pb2.DeleteNativeUserIdentityLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/audit.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/audit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import log_pb2 as admin_dot_v1_dot_types_dot_v1_dot_log__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61\x64min/v1/audit.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/log.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"f\n\x0eGetLogsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x02 \x01(\x05R\x06offset\x12\x1b\n\x06\x66ilter\x18\x03 \x01(\tH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"#\n\x11GetLogByIDRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x0fGetLogsResponse\x12\x30\n\x04logs\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.FormalLogR\x04logs\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore\"D\n\x12GetLogByIDResponse\x12.\n\x03log\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.FormalLogR\x03log\"*\n\x18GetEventBySessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"O\n\x19GetEventBySessionResponse\x12\x32\n\nevent_data\x18\x01 \x03(\x0b\x32\x13.admin.v1.EventDataR\teventData\"\xa6\x01\n\tEventData\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x1d\n\nsession_id\x18\x03 \x01(\tR\tsessionId\x12\x14\n\x05\x62ytes\x18\x04 \x01(\x05R\x05\x62ytes\x12\x16\n\x06offset\x18\x05 \x01(\x05R\x06offset\")\n\x17GetDataBySessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"z\n\x07SshData\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12!\n\x0cmessage_type\x18\x03 \x01(\tR\x0bmessageType\"H\n\x18GetDataBySessionResponse\x12,\n\x08ssh_data\x18\x01 \x03(\x0b\x32\x11.admin.v1.SshDataR\x07sshData2\xdc\x02\n\x10\x41uditLogsService\x12@\n\x07GetLogs\x12\x18.admin.v1.GetLogsRequest\x1a\x19.admin.v1.GetLogsResponse\"\x00\x12I\n\nGetLogByID\x12\x1b.admin.v1.GetLogByIDRequest\x1a\x1c.admin.v1.GetLogByIDResponse\"\x00\x12^\n\x11GetEventBySession\x12\".admin.v1.GetEventBySessionRequest\x1a#.admin.v1.GetEventBySessionResponse\"\x00\x12[\n\x10GetDataBySession\x12!.admin.v1.GetDataBySessionRequest\x1a\".admin.v1.GetDataBySessionResponse\"\x00\x42\xa0\x01\n\x0c\x63om.admin.v1B\nAuditProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.audit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\nAuditProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETLOGSREQUEST']._serialized_start=96
  _globals['_GETLOGSREQUEST']._serialized_end=198
  _globals['_GETLOGBYIDREQUEST']._serialized_start=200
  _globals['_GETLOGBYIDREQUEST']._serialized_end=235
  _globals['_GETLOGSRESPONSE']._serialized_start=237
  _globals['_GETLOGSRESPONSE']._serialized_end=331
  _globals['_GETLOGBYIDRESPONSE']._serialized_start=333
  _globals['_GETLOGBYIDRESPONSE']._serialized_end=401
  _globals['_GETEVENTBYSESSIONREQUEST']._serialized_start=403
  _globals['_GETEVENTBYSESSIONREQUEST']._serialized_end=445
  _globals['_GETEVENTBYSESSIONRESPONSE']._serialized_start=447
  _globals['_GETEVENTBYSESSIONRESPONSE']._serialized_end=526
  _globals['_EVENTDATA']._serialized_start=529
  _globals['_EVENTDATA']._serialized_end=695
  _globals['_GETDATABYSESSIONREQUEST']._serialized_start=697
  _globals['_GETDATABYSESSIONREQUEST']._serialized_end=738
  _globals['_SSHDATA']._serialized_start=740
  _globals['_SSHDATA']._serialized_end=862
  _globals['_GETDATABYSESSIONRESPONSE']._serialized_start=864
  _globals['_GETDATABYSESSIONRESPONSE']._serialized_end=936
  _globals['_AUDITLOGSSERVICE']._serialized_start=939
  _globals['_AUDITLOGSSERVICE']._serialized_end=1287
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_mfa.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_mfa.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_mfa.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"l\n\x1aListIntegrationMfasRequest\x12 \n\x05limit\x18\x01 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xf4\x03 \x00R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"\xa1\x01\n\x1bListIntegrationMfasResponse\x12<\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x18.admin.v1.IntegrationMfaR\x0cintegrations\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"7\n\x1cGetIntegrationMfaByIdRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"[\n\x1dGetIntegrationMfaByIdResponse\x12:\n\x0bintegration\x18\x01 \x01(\x0b\x32\x18.admin.v1.IntegrationMfaR\x0bintegration\"\xf4\x01\n\x1b\x43reateIntegrationMfaRequest\x12\x1e\n\x04type\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05R\x03\x64uoR\x04type\x12.\n\x13\x64uo_integration_key\x18\x02 \x01(\tR\x11\x64uoIntegrationKey\x12$\n\x0e\x64uo_secret_key\x18\x03 \x01(\tR\x0c\x64uoSecretKey\x12(\n\x10\x64uo_api_hostname\x18\x04 \x01(\tR\x0e\x64uoApiHostname\x12\x35\n\x16termination_protection\x18\x05 \x01(\x08R\x15terminationProtection\".\n\x1c\x43reateIntegrationMfaResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"6\n\x1b\x44\x65leteIntegrationMfaRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x1e\n\x1c\x44\x65leteIntegrationMfaResponse\"m\n\x1bUpdateIntegrationMfaRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\"\x1e\n\x1cUpdateIntegrationMfaResponse\"\xe1\x02\n\x0eIntegrationMfa\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x12\n\x04type\x18\x04 \x01(\tR\x04type\x12.\n\x13\x64uo_integration_key\x18\x05 \x01(\tR\x11\x64uoIntegrationKey\x12$\n\x0e\x64uo_secret_key\x18\x06 \x01(\tR\x0c\x64uoSecretKey\x12(\n\x10\x64uo_api_hostname\x18\x07 \x01(\tR\x0e\x64uoApiHostname\x12\x35\n\x16termination_protection\x18\x08 \x01(\x08R\x15terminationProtection2\xa4\x04\n\x15IntegrationMfaService\x12\x64\n\x13ListIntegrationMfas\x12$.admin.v1.ListIntegrationMfasRequest\x1a%.admin.v1.ListIntegrationMfasResponse\"\x00\x12j\n\x15GetIntegrationMfaById\x12&.admin.v1.GetIntegrationMfaByIdRequest\x1a\'.admin.v1.GetIntegrationMfaByIdResponse\"\x00\x12g\n\x14UpdateIntegrationMfa\x12%.admin.v1.UpdateIntegrationMfaRequest\x1a&.admin.v1.UpdateIntegrationMfaResponse\"\x00\x12g\n\x14\x43reateIntegrationMfa\x12%.admin.v1.CreateIntegrationMfaRequest\x1a&.admin.v1.CreateIntegrationMfaResponse\"\x00\x12g\n\x14\x44\x65leteIntegrationMfa\x12%.admin.v1.DeleteIntegrationMfaRequest\x1a&.admin.v1.DeleteIntegrationMfaResponse\"\x00\x42\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationMfaProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_mfa_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationMfaProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTINTEGRATIONMFASREQUEST'].fields_by_name['limit']._loaded_options = None
  _globals['_LISTINTEGRATIONMFASREQUEST'].fields_by_name['limit']._serialized_options = b'\372B\007\032\005\030\364\003 \000'
  _globals['_GETINTEGRATIONMFABYIDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETINTEGRATIONMFABYIDREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINTEGRATIONMFAREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_CREATEINTEGRATIONMFAREQUEST'].fields_by_name['type']._serialized_options = b'\372B\007r\005R\003duo'
  _globals['_DELETEINTEGRATIONMFAREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEINTEGRATIONMFAREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINTEGRATIONMFAREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEINTEGRATIONMFAREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LISTINTEGRATIONMFASREQUEST']._serialized_start=144
  _globals['_LISTINTEGRATIONMFASREQUEST']._serialized_end=252
  _globals['_LISTINTEGRATIONMFASRESPONSE']._serialized_start=255
  _globals['_LISTINTEGRATIONMFASRESPONSE']._serialized_end=416
  _globals['_GETINTEGRATIONMFABYIDREQUEST']._serialized_start=418
  _globals['_GETINTEGRATIONMFABYIDREQUEST']._serialized_end=473
  _globals['_GETINTEGRATIONMFABYIDRESPONSE']._serialized_start=475
  _globals['_GETINTEGRATIONMFABYIDRESPONSE']._serialized_end=566
  _globals['_CREATEINTEGRATIONMFAREQUEST']._serialized_start=569
  _globals['_CREATEINTEGRATIONMFAREQUEST']._serialized_end=813
  _globals['_CREATEINTEGRATIONMFARESPONSE']._serialized_start=815
  _globals['_CREATEINTEGRATIONMFARESPONSE']._serialized_end=861
  _globals['_DELETEINTEGRATIONMFAREQUEST']._serialized_start=863
  _globals['_DELETEINTEGRATIONMFAREQUEST']._serialized_end=917
  _globals['_DELETEINTEGRATIONMFARESPONSE']._serialized_start=919
  _globals['_DELETEINTEGRATIONMFARESPONSE']._serialized_end=949
  _globals['_UPDATEINTEGRATIONMFAREQUEST']._serialized_start=951
  _globals['_UPDATEINTEGRATIONMFAREQUEST']._serialized_end=1060
  _globals['_UPDATEINTEGRATIONMFARESPONSE']._serialized_start=1062
  _globals['_UPDATEINTEGRATIONMFARESPONSE']._serialized_end=1092
  _globals['_INTEGRATIONMFA']._serialized_start=1095
  _globals['_INTEGRATIONMFA']._serialized_end=1448
  _globals['_INTEGRATIONMFASERVICE']._serialized_start=1451
  _globals['_INTEGRATIONMFASERVICE']._serialized_end=1999
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Organization(_message.Message):
    __slots__ = ("id", "name", "allow_profiles_outside_organization", "domains", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALLOW_PROFILES_OUTSIDE_ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    allow_profiles_outside_organization: bool
    domains: _containers.RepeatedCompositeFieldContainer[OrganizationDomain]
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., allow_profiles_outside_organization: bool = ..., domains: _Optional[_Iterable[_Union[OrganizationDomain, _Mapping]]] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class OrganizationDomain(_message.Message):
    __slots__ = ("id", "domain")
    ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    domain: str
    def __init__(self, id: _Optional[str] = ..., domain: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Column(_message.Message):
    __slots__ = ("created_at", "updated_at", "datastore_id", "datastore_name", "path", "table_physical_id", "table_attribute_number", "name", "alias", "table_path", "data_label", "data_type", "data_type_oid", "data_label_locked_for_sidecar", "tags", "encrypted", "policy_action", "decrypted_at_query_time", "decryption_policy_id", "data_domain_ids")
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_LOCKED_FOR_SIDECAR_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    POLICY_ACTION_FIELD_NUMBER: _ClassVar[int]
    DECRYPTED_AT_QUERY_TIME_FIELD_NUMBER: _ClassVar[int]
    DECRYPTION_POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    updated_at: int
    datastore_id: str
    datastore_name: str
    path: str
    table_physical_id: str
    table_attribute_number: int
    name: str
    alias: str
    table_path: str
    data_label: str
    data_type: str
    data_type_oid: int
    data_label_locked_for_sidecar: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    policy_action: str
    decrypted_at_query_time: bool
    decryption_policy_id: str
    data_domain_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., name: _Optional[str] = ..., alias: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., data_label_locked_for_sidecar: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ..., policy_action: _Optional[str] = ..., decrypted_at_query_time: bool = ..., decryption_policy_id: _Optional[str] = ..., data_domain_ids: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/datastore.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/datastore.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/datastore.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\x80\x03\n\x16\x43reateDatastoreRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\x12\x12\n\x04port\x18\x03 \x01(\x05R\x04port\x12\x1e\n\ntechnology\x18\x04 \x01(\tR\ntechnology\x12/\n\x14health_check_db_name\x18\x05 \x01(\tR\x11healthCheckDbName\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\x06 \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x07 \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12 \n\x0b\x65nvironment\x18\x08 \x01(\tR\x0b\x65nvironment\x12\x35\n\x16termination_protection\x18\t \x01(\x08R\x15terminationProtection\")\n\x17\x43reateDatastoreResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"%\n\x13GetDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x14GetDatastoreResponse\x12\x31\n\tdatastore\x18\x01 \x01(\x0b\x32\x13.admin.v1.DatastoreR\tdatastore\"\xea\x01\n\x14GetDatastoresRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\x12\x16\n\x06search\x18\x05 \x01(\tR\x06search\x12^\n\rsearch_fields\x18\x06 \x03(\tB9\xfa\x42\x36\x92\x01\x33\"1r/R\x04nameR\x08hostnameR\x04portR\ntechnologyR\x0b\x65nvironmentR\x0csearchFields\"\x92\x01\n\x15GetDatastoresResponse\x12\x33\n\ndatastores\x18\x01 \x03(\x0b\x32\x13.admin.v1.DatastoreR\ndatastores\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"(\n\x16\x44\x65leteDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteDatastoreResponse\"@\n\x1aUpdateDatastoreNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x1d\n\x1bUpdateDatastoreNameResponse\"\xaa\x01\n\x1eUpdateDbDiscoveryConfigRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\x02 \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x03 \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\"!\n\x1fUpdateDbDiscoveryConfigResponse\"j\n\'UpdateDataStoreHealthCheckDbNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12/\n\x14health_check_db_name\x18\x02 \x01(\tR\x11healthCheckDbName\"*\n(UpdateDataStoreHealthCheckDbNameResponse\"u\n+UpdateDataStoreDefaultAccessBehaviorRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\x02 \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\".\n,UpdateDataStoreDefaultAccessBehaviorResponse\"h\n\x1fSetTerminationProtectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\"\"\n SetTerminationProtectionResponse\"*\n\x18GetLinkedSidecarsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x19GetLinkedSidecarsResponse\x12\x33\n\x08sidecars\x18\x01 \x03(\x0b\x32\x17.admin.v1.LinkedSidecarR\x08sidecars\"h\n\rLinkedSidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x03 \x01(\tR\x08hostname\x12\x17\n\x07link_id\x18\x04 \x01(\tR\x06linkId\"\xf1\x04\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x12\n\x04port\x18\x04 \x01(\x05R\x04port\x12\x1a\n\x08hostname\x18\x05 \x01(\tR\x08hostname\x12/\n\x14health_check_db_name\x18\x06 \x01(\tR\x11healthCheckDbName\x12\x1e\n\ntechnology\x18\x07 \x01(\tR\ntechnology\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1b\n\texpire_at\x18\t \x01(\tR\x08\x65xpireAt\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\n \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x0b \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\x0c \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\x12\x39\n\x0blinked_logs\x18\r \x03(\x0b\x32\x18.admin.v1.IntegrationLogR\nlinkedLogs\x12 \n\x0b\x65nvironment\x18\x0e \x01(\tR\x0b\x65nvironment\x12\x35\n\x16termination_protection\x18\x0f \x01(\x08R\x15terminationProtection\"g\n\x0eIntegrationLog\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x1d\n\ncreated_at\x18\x04 \x01(\x05R\tcreatedAt2\xac\x08\n\x10\x44\x61taStoreService\x12V\n\x0f\x43reateDatastore\x12 .admin.v1.CreateDatastoreRequest\x1a!.admin.v1.CreateDatastoreResponse\x12M\n\x0cGetDatastore\x12\x1d.admin.v1.GetDatastoreRequest\x1a\x1e.admin.v1.GetDatastoreResponse\x12P\n\rGetDatastores\x12\x1e.admin.v1.GetDatastoresRequest\x1a\x1f.admin.v1.GetDatastoresResponse\x12\\\n\x11GetLinkedSidecars\x12\".admin.v1.GetLinkedSidecarsRequest\x1a#.admin.v1.GetLinkedSidecarsResponse\x12V\n\x0f\x44\x65leteDatastore\x12 .admin.v1.DeleteDatastoreRequest\x1a!.admin.v1.DeleteDatastoreResponse\x12\x62\n\x13UpdateDatastoreName\x12$.admin.v1.UpdateDatastoreNameRequest\x1a%.admin.v1.UpdateDatastoreNameResponse\x12n\n\x17UpdateDbDiscoveryConfig\x12(.admin.v1.UpdateDbDiscoveryConfigRequest\x1a).admin.v1.UpdateDbDiscoveryConfigResponse\x12\x89\x01\n UpdateDataStoreHealthCheckDbName\x12\x31.admin.v1.UpdateDataStoreHealthCheckDbNameRequest\x1a\x32.admin.v1.UpdateDataStoreHealthCheckDbNameResponse\x12\x95\x01\n$UpdateDataStoreDefaultAccessBehavior\x12\x35.admin.v1.UpdateDataStoreDefaultAccessBehaviorRequest\x1a\x36.admin.v1.UpdateDataStoreDefaultAccessBehaviorResponse\x12q\n\x18SetTerminationProtection\x12).admin.v1.SetTerminationProtectionRequest\x1a*.admin.v1.SetTerminationProtectionResponseB\xa4\x01\n\x0c\x63om.admin.v1B\x0e\x44\x61tastoreProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.datastore_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016DatastoreProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDATASTORESREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_GETDATASTORESREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B6\222\0013\"1r/R\004nameR\010hostnameR\004portR\ntechnologyR\013environment'
  _globals['_CREATEDATASTOREREQUEST']._serialized_start=139
  _globals['_CREATEDATASTOREREQUEST']._serialized_end=523
  _globals['_CREATEDATASTORERESPONSE']._serialized_start=525
  _globals['_CREATEDATASTORERESPONSE']._serialized_end=566
  _globals['_GETDATASTOREREQUEST']._serialized_start=568
  _globals['_GETDATASTOREREQUEST']._serialized_end=605
  _globals['_GETDATASTORERESPONSE']._serialized_start=607
  _globals['_GETDATASTORERESPONSE']._serialized_end=680
  _globals['_GETDATASTORESREQUEST']._serialized_start=683
  _globals['_GETDATASTORESREQUEST']._serialized_end=917
  _globals['_GETDATASTORESRESPONSE']._serialized_start=920
  _globals['_GETDATASTORESRESPONSE']._serialized_end=1066
  _globals['_DELETEDATASTOREREQUEST']._serialized_start=1068
  _globals['_DELETEDATASTOREREQUEST']._serialized_end=1108
  _globals['_DELETEDATASTORERESPONSE']._serialized_start=1110
  _globals['_DELETEDATASTORERESPONSE']._serialized_end=1135
  _globals['_UPDATEDATASTORENAMEREQUEST']._serialized_start=1137
  _globals['_UPDATEDATASTORENAMEREQUEST']._serialized_end=1201
  _globals['_UPDATEDATASTORENAMERESPONSE']._serialized_start=1203
  _globals['_UPDATEDATASTORENAMERESPONSE']._serialized_end=1232
  _globals['_UPDATEDBDISCOVERYCONFIGREQUEST']._serialized_start=1235
  _globals['_UPDATEDBDISCOVERYCONFIGREQUEST']._serialized_end=1405
  _globals['_UPDATEDBDISCOVERYCONFIGRESPONSE']._serialized_start=1407
  _globals['_UPDATEDBDISCOVERYCONFIGRESPONSE']._serialized_end=1440
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMEREQUEST']._serialized_start=1442
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMEREQUEST']._serialized_end=1548
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMERESPONSE']._serialized_start=1550
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMERESPONSE']._serialized_end=1592
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORREQUEST']._serialized_start=1594
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORREQUEST']._serialized_end=1711
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORRESPONSE']._serialized_start=1713
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORRESPONSE']._serialized_end=1759
  _globals['_SETTERMINATIONPROTECTIONREQUEST']._serialized_start=1761
  _globals['_SETTERMINATIONPROTECTIONREQUEST']._serialized_end=1865
  _globals['_SETTERMINATIONPROTECTIONRESPONSE']._serialized_start=1867
  _globals['_SETTERMINATIONPROTECTIONRESPONSE']._serialized_end=1901
  _globals['_GETLINKEDSIDECARSREQUEST']._serialized_start=1903
  _globals['_GETLINKEDSIDECARSREQUEST']._serialized_end=1945
  _globals['_GETLINKEDSIDECARSRESPONSE']._serialized_start=1947
  _globals['_GETLINKEDSIDECARSRESPONSE']._serialized_end=2027
  _globals['_LINKEDSIDECAR']._serialized_start=2029
  _globals['_LINKEDSIDECAR']._serialized_end=2133
  _globals['_DATASTORE']._serialized_start=2136
  _globals['_DATASTORE']._serialized_end=2761
  _globals['_INTEGRATIONLOG']._serialized_start=2763
  _globals['_INTEGRATIONLOG']._serialized_end=2866
  _globals['_DATASTORESERVICE']._serialized_start=2869
  _globals['_DATASTORESERVICE']._serialized_end=3937
# @@protoc_insertion_point(module_scope)



from . import integration_sso, registry, permissions, satellite, identities, encryption, etl, metrics, datastore, integration_code_repository, integration_github, inventory, sidecar, integration_app, cord, integration_kms, work_os, audit, integration_slack, policies, integration_mfa, native_user, search, admin, integration_datahub, integration_cloud, integration_external_api, integration_log
import grpc

SERVER_URL = "adminv2.api.formalcloud.net:443"

class Client(object):
	"""Formal Admin API Client"""

	def __init__(self, api_key):
		"""Constructor.

		Args:
			api_key: Formal API Key
		"""
		self.SsoClient = integration_sso.SsoService(SERVER_URL, api_key)
		self.RegistryClient = registry.RegistryService(SERVER_URL, api_key)
		self.PermissionClient = permissions.PermissionService(SERVER_URL, api_key)
		self.SatelliteClient = satellite.SatelliteService(SERVER_URL, api_key)
		self.UserClient = identities.UserService(SERVER_URL, api_key)
		self.GroupClient = identities.GroupService(SERVER_URL, api_key)
		self.FieldEncryptionPolicyClient = encryption.FieldEncryptionPolicyService(SERVER_URL, api_key)
		self.FieldEncryptionClient = encryption.FieldEncryptionService(SERVER_URL, api_key)
		self.ETLClient = etl.ETLService(SERVER_URL, api_key)
		self.MetricsClient = metrics.MetricsService(SERVER_URL, api_key)
		self.DataStoreClient = datastore.DataStoreService(SERVER_URL, api_key)
		self.CodeRepositoryClient = integration_code_repository.CodeRepositoryService(SERVER_URL, api_key)
		self.GithubClient = integration_github.GithubService(SERVER_URL, api_key)
		self.InventoryClient = inventory.InventoryService(SERVER_URL, api_key)
		self.SidecarClient = sidecar.SidecarService(SERVER_URL, api_key)
		self.AppClient = integration_app.AppService(SERVER_URL, api_key)
		self.CordClient = cord.CordService(SERVER_URL, api_key)
		self.KmsClient = integration_kms.KmsService(SERVER_URL, api_key)
		self.DSyncClient = work_os.DSyncService(SERVER_URL, api_key)
		self.AuditLogsClient = audit.AuditLogsService(SERVER_URL, api_key)
		self.SlackClient = integration_slack.SlackService(SERVER_URL, api_key)
		self.PolicyClient = policies.PolicyService(SERVER_URL, api_key)
		self.IntegrationMfaClient = integration_mfa.IntegrationMfaService(SERVER_URL, api_key)
		self.NativeUserClient = native_user.NativeUserService(SERVER_URL, api_key)
		self.SearchClient = search.SearchService(SERVER_URL, api_key)
		self.DevClient = admin.DevService(SERVER_URL, api_key)
		self.DatahubClient = integration_datahub.DatahubService(SERVER_URL, api_key)
		self.CloudClient = integration_cloud.CloudService(SERVER_URL, api_key)
		self.ExternalApiClient = integration_external_api.ExternalApiService(SERVER_URL, api_key)
		self.LogsClient = integration_log.LogsService(SERVER_URL, api_key)



import os
import formal_sdk

if __name__ == '__main__':
    # Import data types for the requests
    # example: from formal_sdk.gen.admin.v1.client_name_pb2 import methodNameRequest
    # for NativeUserClient it will be native_user_pb2
    # the client_name_pb2 contains the request and response class
    # for example: CreateNativeUserRequest for CreateNativeUser method
    from formal_sdk.gen.admin.v1.native_user_pb2 import CreateNativeUserRequest

    # Initialize formal client
    api_key = os.environ.get('API_KEY')
    formal_client = formal_sdk.Client(api_key)

    # Create Native Role
    data_store_id = ""
    native_user_id = ""
    native_user_secret = ""
    use_as_default = False

    createdRole = formal_client.NativeUserClient.CreateNativeUser(CreateNativeUserRequest(
        data_store_id=data_store_id,
        native_user_id=native_user_id,
        native_user_secret=native_user_secret,
        use_as_default=use_as_default)
        )

    # Get Native Role
    from formal_sdk.gen.admin.v1.native_user_pb2 import GetNativeUserRequest
    # NOTE: inline import intended for examples to see the import pattern, follow PEP 8 recommendation to import on your code

    previousRole = formal_client.NativeUserClient.GetNativeUser(
        GetNativeUserRequest(data_store_id=data_store_id, native_user_id=native_user_id)
        )

    print(f'data_store_id: {previousRole.native_user.datastore_id}')
    print(f'native_role_id: {previousRole.native_user.native_user_id}')
    print(f'native_role_secret: {previousRole.native_user.native_user_secret}')
    print(f'use_as_default: {previousRole.native_user.use_as_default}')

    # Get sidecar tls certificate and private key
    from formal_sdk.gen.admin.v1.sidecar_pb2 import GetSidecarTlsCertificateByIdRequest 
    # NOTE: inline import intended for examples to see the import pattern, follow PEP 8 recommendation to import on your code

    sidecar_id = ""
    secret = formal_client.SidecarClient.GetSidecarTlsCertificateById(GetSidecarTlsCertificateByIdRequest(id=sidecar_id))
    print(f'secret: {secret.secret}')

    # Empty request parameter example
    from formal_sdk.gen.admin.v1.identities_pb2 import GetUsersRequest
    # NOTE: inline import intended for examples to see the import pattern, follow PEP 8 recommendation to import on your code

    user_client = formal_client.UserClient
    print(user_client.GetUsers(GetUsersRequest())) # empty param need to pass the request object without any param
    print(user_client.GetUsers(GetUsersRequest()).users[0].id)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IncidentAccount(_message.Message):
    __slots__ = ["id", "name", "type", "logo", "api_key"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LOGO_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: str
    logo: str
    api_key: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., logo: _Optional[str] = ..., api_key: _Optional[str] = ...) -> None: ...



from .types.v1 import flat_dataplane_pb2 as _flat_dataplane_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDataplaneByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataplaneByIdResponse(_message.Message):
    __slots__ = ("dataplane",)
    DATAPLANE_FIELD_NUMBER: _ClassVar[int]
    dataplane: _flat_dataplane_pb2.FlatDataplane
    def __init__(self, dataplane: _Optional[_Union[_flat_dataplane_pb2.FlatDataplane, _Mapping]] = ...) -> None: ...

class GetDataplaneRoutesByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataplaneRoutesByIdResponse(_message.Message):
    __slots__ = ("dataplane_routes",)
    DATAPLANE_ROUTES_FIELD_NUMBER: _ClassVar[int]
    dataplane_routes: _flat_dataplane_pb2.DataplaneTransitGatewayRoutes
    def __init__(self, dataplane_routes: _Optional[_Union[_flat_dataplane_pb2.DataplaneTransitGatewayRoutes, _Mapping]] = ...) -> None: ...

class CreateAwsConnectionSessionRequest(_message.Message):
    __slots__ = ("cloud_account_name", "cloud_account_region")
    CLOUD_ACCOUNT_NAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_REGION_FIELD_NUMBER: _ClassVar[int]
    cloud_account_name: str
    cloud_account_region: str
    def __init__(self, cloud_account_name: _Optional[str] = ..., cloud_account_region: _Optional[str] = ...) -> None: ...

class CreateAwsConnectionSessionResponse(_message.Message):
    __slots__ = ("cloud_integration",)
    CLOUD_INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    cloud_integration: _flat_dataplane_pb2.CloudIntegration
    def __init__(self, cloud_integration: _Optional[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]] = ...) -> None: ...

class DeleteAwsConnectionSessionRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationsCloudAccountByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationsCloudAccountByIdResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _flat_dataplane_pb2.CloudIntegration
    def __init__(self, integration: _Optional[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]] = ...) -> None: ...

class GetIntegrationsCloudAccountsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIntegrationsCloudAccountsResponse(_message.Message):
    __slots__ = ("integrations",)
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[_flat_dataplane_pb2.CloudIntegration]
    def __init__(self, integrations: _Optional[_Iterable[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]]] = ...) -> None: ...

class CreateGcpConnectionSessionRequest(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class CreateGcpConnectionSessionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteAwsConnectionSessionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetDataplaneStacksByCloudAccountIdRequest(_message.Message):
    __slots__ = ("cloud_account_id",)
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    cloud_account_id: str
    def __init__(self, cloud_account_id: _Optional[str] = ...) -> None: ...

class GetDataplaneStacksByCloudAccountIdResponse(_message.Message):
    __slots__ = ("dataplanes",)
    DATAPLANES_FIELD_NUMBER: _ClassVar[int]
    dataplanes: _containers.RepeatedCompositeFieldContainer[_flat_dataplane_pb2.FlatDataplane]
    def __init__(self, dataplanes: _Optional[_Iterable[_Union[_flat_dataplane_pb2.FlatDataplane, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_sso.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_sso.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import connection_pb2 as admin_dot_v1_dot_types_dot_v1_dot_connection__pb2
from .types.v1 import organization_pb2 as admin_dot_v1_dot_types_dot_v1_dot_organization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_sso.proto\x12\x08\x61\x64min.v1\x1a\"admin/v1/types/v1/connection.proto\x1a$admin/v1/types/v1/organization.proto\"\x15\n\x13GetWorkOsOrgRequest\"x\n\x14GetWorkOsOrgResponse\x12>\n\nworkos_org\x18\x01 \x01(\x0b\x32\x1f.admin.v1.types.v1.OrganizationR\tworkosOrg\x12 \n\x0cself_sign_up\x18\x02 \x01(\x08R\nselfSignUp\"T\n\x16UpdateWorkOsOrgRequest\x12\x18\n\x07\x64omains\x18\x01 \x03(\tR\x07\x64omains\x12 \n\x0cself_sign_up\x18\x02 \x01(\x08R\nselfSignUp\"\x19\n\x17UpdateWorkOsOrgResponse\"\x1a\n\x18GetSsoConnectionsRequest\"\\\n\x19GetSsoConnectionsResponse\x12?\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ConnectionR\x0b\x63onnections\")\n\x17\x44\x65leteConnectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1a\n\x18\x44\x65leteConnectionResponse2\xec\x02\n\nSsoService\x12M\n\x0cGetWorkOsOrg\x12\x1d.admin.v1.GetWorkOsOrgRequest\x1a\x1e.admin.v1.GetWorkOsOrgResponse\x12V\n\x0fUpdateWorkOsOrg\x12 .admin.v1.UpdateWorkOsOrgRequest\x1a!.admin.v1.UpdateWorkOsOrgResponse\x12\\\n\x11GetSsoConnections\x12\".admin.v1.GetSsoConnectionsRequest\x1a#.admin.v1.GetSsoConnectionsResponse\x12Y\n\x10\x44\x65leteConnection\x12!.admin.v1.DeleteConnectionRequest\x1a\".admin.v1.DeleteConnectionResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationSsoProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_sso_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationSsoProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETWORKOSORGREQUEST']._serialized_start=118
  _globals['_GETWORKOSORGREQUEST']._serialized_end=139
  _globals['_GETWORKOSORGRESPONSE']._serialized_start=141
  _globals['_GETWORKOSORGRESPONSE']._serialized_end=261
  _globals['_UPDATEWORKOSORGREQUEST']._serialized_start=263
  _globals['_UPDATEWORKOSORGREQUEST']._serialized_end=347
  _globals['_UPDATEWORKOSORGRESPONSE']._serialized_start=349
  _globals['_UPDATEWORKOSORGRESPONSE']._serialized_end=374
  _globals['_GETSSOCONNECTIONSREQUEST']._serialized_start=376
  _globals['_GETSSOCONNECTIONSREQUEST']._serialized_end=402
  _globals['_GETSSOCONNECTIONSRESPONSE']._serialized_start=404
  _globals['_GETSSOCONNECTIONSRESPONSE']._serialized_end=496
  _globals['_DELETECONNECTIONREQUEST']._serialized_start=498
  _globals['_DELETECONNECTIONREQUEST']._serialized_end=539
  _globals['_DELETECONNECTIONRESPONSE']._serialized_start=541
  _globals['_DELETECONNECTIONRESPONSE']._serialized_end=567
  _globals['_SSOSERVICE']._serialized_start=570
  _globals['_SSOSERVICE']._serialized_end=934
# @@protoc_insertion_point(module_scope)



from .types.v1 import app_pb2 as _app_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RefreshIntegrationAppsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RefreshIntegrationAppsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIntegrationAppsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIntegrationAppsResponse(_message.Message):
    __slots__ = ("integrations",)
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[_app_pb2.IntegrationApp]
    def __init__(self, integrations: _Optional[_Iterable[_Union[_app_pb2.IntegrationApp, _Mapping]]] = ...) -> None: ...

class GetIntegrationByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationByIdResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _app_pb2.IntegrationApp
    def __init__(self, integration: _Optional[_Union[_app_pb2.IntegrationApp, _Mapping]] = ...) -> None: ...

class CreateIntegrationAppRequest(_message.Message):
    __slots__ = ("name", "type", "metabase_hostname", "metabase_username", "metabase_password", "linked_db_user_id", "fivetran_api_key", "fivetran_api_secret")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    METABASE_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    METABASE_USERNAME_FIELD_NUMBER: _ClassVar[int]
    METABASE_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    LINKED_DB_USER_ID_FIELD_NUMBER: _ClassVar[int]
    FIVETRAN_API_KEY_FIELD_NUMBER: _ClassVar[int]
    FIVETRAN_API_SECRET_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    metabase_hostname: str
    metabase_username: str
    metabase_password: str
    linked_db_user_id: str
    fivetran_api_key: str
    fivetran_api_secret: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., metabase_hostname: _Optional[str] = ..., metabase_username: _Optional[str] = ..., metabase_password: _Optional[str] = ..., linked_db_user_id: _Optional[str] = ..., fivetran_api_key: _Optional[str] = ..., fivetran_api_secret: _Optional[str] = ...) -> None: ...

class CreateIntegrationAppResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _app_pb2.IntegrationApp
    def __init__(self, integration: _Optional[_Union[_app_pb2.IntegrationApp, _Mapping]] = ...) -> None: ...

class DeleteIntegrationAppRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteIntegrationAppResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from .types.v1 import search_pb2 as _search_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SearchRequest(_message.Message):
    __slots__ = ("object_type", "query", "filter_by", "sort_by", "page", "limit")
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    FILTER_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    object_type: str
    query: str
    filter_by: str
    sort_by: str
    page: int
    limit: int
    def __init__(self, object_type: _Optional[str] = ..., query: _Optional[str] = ..., filter_by: _Optional[str] = ..., sort_by: _Optional[str] = ..., page: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("users", "groups", "policies", "datastores", "sidecars", "inventories", "found", "page", "out_of", "search_time_ms", "search_cutoff")
    USERS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    POLICIES_FIELD_NUMBER: _ClassVar[int]
    DATASTORES_FIELD_NUMBER: _ClassVar[int]
    SIDECARS_FIELD_NUMBER: _ClassVar[int]
    INVENTORIES_FIELD_NUMBER: _ClassVar[int]
    FOUND_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    OUT_OF_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TIME_MS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_CUTOFF_FIELD_NUMBER: _ClassVar[int]
    users: WrappedSearchUser
    groups: WrappedSearchGroup
    policies: WrappedSearchPolicy
    datastores: WrappedSearchDatastore
    sidecars: WrappedSearchSidecar
    inventories: WrappedSearchInventory
    found: int
    page: int
    out_of: int
    search_time_ms: int
    search_cutoff: bool
    def __init__(self, users: _Optional[_Union[WrappedSearchUser, _Mapping]] = ..., groups: _Optional[_Union[WrappedSearchGroup, _Mapping]] = ..., policies: _Optional[_Union[WrappedSearchPolicy, _Mapping]] = ..., datastores: _Optional[_Union[WrappedSearchDatastore, _Mapping]] = ..., sidecars: _Optional[_Union[WrappedSearchSidecar, _Mapping]] = ..., inventories: _Optional[_Union[WrappedSearchInventory, _Mapping]] = ..., found: _Optional[int] = ..., page: _Optional[int] = ..., out_of: _Optional[int] = ..., search_time_ms: _Optional[int] = ..., search_cutoff: bool = ...) -> None: ...

class WrappedSearchUser(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchUser]
    def __init__(self, user: _Optional[_Iterable[_Union[_search_pb2.SearchUser, _Mapping]]] = ...) -> None: ...

class WrappedSearchGroup(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchGroup]
    def __init__(self, group: _Optional[_Iterable[_Union[_search_pb2.SearchGroup, _Mapping]]] = ...) -> None: ...

class WrappedSearchPolicy(_message.Message):
    __slots__ = ("policy",)
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchPolicy]
    def __init__(self, policy: _Optional[_Iterable[_Union[_search_pb2.SearchPolicy, _Mapping]]] = ...) -> None: ...

class WrappedSearchDatastore(_message.Message):
    __slots__ = ("datastore",)
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    datastore: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchDatastore]
    def __init__(self, datastore: _Optional[_Iterable[_Union[_search_pb2.SearchDatastore, _Mapping]]] = ...) -> None: ...

class WrappedSearchSidecar(_message.Message):
    __slots__ = ("sidecar",)
    SIDECAR_FIELD_NUMBER: _ClassVar[int]
    sidecar: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchSidecar]
    def __init__(self, sidecar: _Optional[_Iterable[_Union[_search_pb2.SearchSidecar, _Mapping]]] = ...) -> None: ...

class WrappedSearchInventory(_message.Message):
    __slots__ = ("inventory",)
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[_search_pb2.SearchInventory]
    def __init__(self, inventory: _Optional[_Iterable[_Union[_search_pb2.SearchInventory, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/etl.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/etl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import datastore_pb2 as admin_dot_v1_dot_types_dot_v1_dot_datastore__pb2
from .types.v1 import etl_pb2 as admin_dot_v1_dot_types_dot_v1_dot_etl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61\x64min/v1/etl.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/datastore.proto\x1a\x1b\x61\x64min/v1/types/v1/etl.proto\"\x12\n\x10GetGroupsRequest\"H\n\x11GetGroupsResponse\x12\x33\n\x06groups\x18\x01 \x03(\x0b\x32\x1b.admin.v1.types.v1.ETLGroupR\x06groups\"2\n\x14GetConnectorsRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\"X\n\x15GetConnectorsResponse\x12?\n\nconnectors\x18\x01 \x03(\x0b\x32\x1f.admin.v1.types.v1.ETLConnectorR\nconnectors\"R\n\x1bGetConnectorByDbNameRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\x12\x17\n\x07\x64\x62_name\x18\x02 \x01(\tR\x06\x64\x62Name\"\x99\x01\n\x1cGetConnectorByDbNameResponse\x12=\n\tconnector\x18\x01 \x01(\x0b\x32\x1f.admin.v1.types.v1.ETLConnectorR\tconnector\x12:\n\tdatastore\x18\x02 \x01(\x0b\x32\x1c.admin.v1.types.v1.DatastoreR\tdatastore\"4\n\x16GetDestinationsRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\"`\n\x17GetDestinationsResponse\x12\x45\n\x0c\x64\x65stinations\x18\x01 \x03(\x0b\x32!.admin.v1.types.v1.ETLDestinationR\x0c\x64\x65stinations\"+\n\x19GetDestinationByIDRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x9d\x01\n\x1aGetDestinationByIDResponse\x12\x43\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.ETLDestinationR\x0b\x64\x65stination\x12:\n\tdatastore\x18\x02 \x01(\x0b\x32\x1c.admin.v1.types.v1.DatastoreR\tdatastore\"=\n\x18GetLineageSchemasRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"Z\n\x19GetLineageSchemasResponse\x12=\n\x07schemas\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLSchemaLineageR\x07schemas\"c\n\x1dGetLineageSchemaByNameRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x1f\n\x0bschema_name\x18\x02 \x01(\tR\nschemaName\"]\n\x1eGetLineageSchemaByNameResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.ETLSchemaLineageR\x06schema\"<\n\x17GetLineageTablesRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"V\n\x18GetLineageTablesResponse\x12:\n\x06tables\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.ETLTableLineageR\x06tables\"}\n\x1cGetLineageTableByNameRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x1b\n\tschema_id\x18\x02 \x01(\tR\x08schemaId\x12\x1d\n\ntable_name\x18\x03 \x01(\tR\ttableName\"Y\n\x1dGetLineageTableByNameResponse\x12\x38\n\x05table\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.ETLTableLineageR\x05table\"=\n\x18GetLineageColumnsRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"Z\n\x19GetLineageColumnsResponse\x12=\n\x07\x63olumns\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLColumnLineageR\x07\x63olumns\"_\n\x1fGetLineageColumnsByTableRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x19\n\x08table_id\x18\x02 \x01(\tR\x07tableId\"a\n GetLineageColumnsByTableResponse\x12=\n\x07\x63olumns\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLColumnLineageR\x07\x63olumns2\xbb\x08\n\nETLService\x12R\n\rGetConnectors\x12\x1e.admin.v1.GetConnectorsRequest\x1a\x1f.admin.v1.GetConnectorsResponse\"\x00\x12g\n\x14GetConnectorByDbName\x12%.admin.v1.GetConnectorByDbNameRequest\x1a&.admin.v1.GetConnectorByDbNameResponse\"\x00\x12X\n\x0fGetDestinations\x12 .admin.v1.GetDestinationsRequest\x1a!.admin.v1.GetDestinationsResponse\"\x00\x12\x61\n\x12GetDestinationByID\x12#.admin.v1.GetDestinationByIDRequest\x1a$.admin.v1.GetDestinationByIDResponse\"\x00\x12\x46\n\tGetGroups\x12\x1a.admin.v1.GetGroupsRequest\x1a\x1b.admin.v1.GetGroupsResponse\"\x00\x12^\n\x11GetLineageSchemas\x12\".admin.v1.GetLineageSchemasRequest\x1a#.admin.v1.GetLineageSchemasResponse\"\x00\x12m\n\x16GetLineageSchemaByName\x12\'.admin.v1.GetLineageSchemaByNameRequest\x1a(.admin.v1.GetLineageSchemaByNameResponse\"\x00\x12[\n\x10GetLineageTables\x12!.admin.v1.GetLineageTablesRequest\x1a\".admin.v1.GetLineageTablesResponse\"\x00\x12j\n\x15GetLineageTableByName\x12&.admin.v1.GetLineageTableByNameRequest\x1a\'.admin.v1.GetLineageTableByNameResponse\"\x00\x12^\n\x11GetLineageColumns\x12\".admin.v1.GetLineageColumnsRequest\x1a#.admin.v1.GetLineageColumnsResponse\"\x00\x12s\n\x18GetLineageColumnsByTable\x12).admin.v1.GetLineageColumnsByTableRequest\x1a*.admin.v1.GetLineageColumnsByTableResponse\"\x00\x42\x9e\x01\n\x0c\x63om.admin.v1B\x08\x45tlProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.etl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\010EtlProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETGROUPSREQUEST']._serialized_start=96
  _globals['_GETGROUPSREQUEST']._serialized_end=114
  _globals['_GETGROUPSRESPONSE']._serialized_start=116
  _globals['_GETGROUPSRESPONSE']._serialized_end=188
  _globals['_GETCONNECTORSREQUEST']._serialized_start=190
  _globals['_GETCONNECTORSREQUEST']._serialized_end=240
  _globals['_GETCONNECTORSRESPONSE']._serialized_start=242
  _globals['_GETCONNECTORSRESPONSE']._serialized_end=330
  _globals['_GETCONNECTORBYDBNAMEREQUEST']._serialized_start=332
  _globals['_GETCONNECTORBYDBNAMEREQUEST']._serialized_end=414
  _globals['_GETCONNECTORBYDBNAMERESPONSE']._serialized_start=417
  _globals['_GETCONNECTORBYDBNAMERESPONSE']._serialized_end=570
  _globals['_GETDESTINATIONSREQUEST']._serialized_start=572
  _globals['_GETDESTINATIONSREQUEST']._serialized_end=624
  _globals['_GETDESTINATIONSRESPONSE']._serialized_start=626
  _globals['_GETDESTINATIONSRESPONSE']._serialized_end=722
  _globals['_GETDESTINATIONBYIDREQUEST']._serialized_start=724
  _globals['_GETDESTINATIONBYIDREQUEST']._serialized_end=767
  _globals['_GETDESTINATIONBYIDRESPONSE']._serialized_start=770
  _globals['_GETDESTINATIONBYIDRESPONSE']._serialized_end=927
  _globals['_GETLINEAGESCHEMASREQUEST']._serialized_start=929
  _globals['_GETLINEAGESCHEMASREQUEST']._serialized_end=990
  _globals['_GETLINEAGESCHEMASRESPONSE']._serialized_start=992
  _globals['_GETLINEAGESCHEMASRESPONSE']._serialized_end=1082
  _globals['_GETLINEAGESCHEMABYNAMEREQUEST']._serialized_start=1084
  _globals['_GETLINEAGESCHEMABYNAMEREQUEST']._serialized_end=1183
  _globals['_GETLINEAGESCHEMABYNAMERESPONSE']._serialized_start=1185
  _globals['_GETLINEAGESCHEMABYNAMERESPONSE']._serialized_end=1278
  _globals['_GETLINEAGETABLESREQUEST']._serialized_start=1280
  _globals['_GETLINEAGETABLESREQUEST']._serialized_end=1340
  _globals['_GETLINEAGETABLESRESPONSE']._serialized_start=1342
  _globals['_GETLINEAGETABLESRESPONSE']._serialized_end=1428
  _globals['_GETLINEAGETABLEBYNAMEREQUEST']._serialized_start=1430
  _globals['_GETLINEAGETABLEBYNAMEREQUEST']._serialized_end=1555
  _globals['_GETLINEAGETABLEBYNAMERESPONSE']._serialized_start=1557
  _globals['_GETLINEAGETABLEBYNAMERESPONSE']._serialized_end=1646
  _globals['_GETLINEAGECOLUMNSREQUEST']._serialized_start=1648
  _globals['_GETLINEAGECOLUMNSREQUEST']._serialized_end=1709
  _globals['_GETLINEAGECOLUMNSRESPONSE']._serialized_start=1711
  _globals['_GETLINEAGECOLUMNSRESPONSE']._serialized_end=1801
  _globals['_GETLINEAGECOLUMNSBYTABLEREQUEST']._serialized_start=1803
  _globals['_GETLINEAGECOLUMNSBYTABLEREQUEST']._serialized_end=1898
  _globals['_GETLINEAGECOLUMNSBYTABLERESPONSE']._serialized_start=1900
  _globals['_GETLINEAGECOLUMNSBYTABLERESPONSE']._serialized_end=1997
  _globals['_ETLSERVICE']._serialized_start=2000
  _globals['_ETLSERVICE']._serialized_end=3083
# @@protoc_insertion_point(module_scope)
